@@ -100,8 +100,9 @@ SelectServer::~SelectServer() {
   DrainCallbacks();
 
   STLDeleteElements(&m_loop_callbacks);
-  if (m_free_clock)
+  if (m_free_clock) {
     delete m_clock;
+  }
 }
 
 const TimeStamp *SelectServer::WakeUpTime() const {
@@ -113,8 +114,9 @@ const TimeStamp *SelectServer::WakeUpTime() const {
 }
 
 void SelectServer::Terminate() {
-  if (m_is_running)
+  if (m_is_running) {
     Execute(NewSingleCallback(this, &SelectServer::SetTerminate));
+  }
 }
 
 void SelectServer::SetDefaultInterval(const TimeInterval &poll_interval) {
@@ -131,8 +133,9 @@ void SelectServer::Run() {
   m_terminate = false;
   while (!m_terminate) {
     // false indicates an error in CheckForEvents();
-    if (!CheckForEvents(m_poll_interval))
+    if (!CheckForEvents(m_poll_interval)) {
       break;
+    }
   }
   m_is_running = false;
 }
@@ -338,8 +341,9 @@ bool SelectServer::CheckForEvents(const TimeInterval &poll_interval) {
   LoopClosureSet::iterator loop_iter;
   for (loop_iter = m_loop_callbacks.begin();
        loop_iter != m_loop_callbacks.end();
-       ++loop_iter)
+       ++loop_iter) {
     (*loop_iter)->Run();
+  }
 
   TimeInterval default_poll_interval = poll_interval;
   // if we've been told to terminate, make this very short.
