@@ -29,19 +29,25 @@
 
 #include <map>
 #include <memory>
-#include <set>
 #include <string>
 #include <utility>
 #include <vector>
 
+#include "libs/usb/Types.h"
+#include "libs/usb/HotplugAgent.h"
+
 #include "ola/base/Macro.h"
-#include "ola/thread/Mutex.h"
-#include "ola/thread/Thread.h"
+#include "ola/thread/Future.h"
+#include "olad/Preferences.h"
 #include "plugins/usbdmx/PluginImplInterface.h"
 #include "plugins/usbdmx/SyncronizedWidgetObserver.h"
 #include "plugins/usbdmx/WidgetFactory.h"
 
 namespace ola {
+namespace usb {
+class LibUsbThread;
+class AsyncronousLibUsbAdaptor;
+}  // namespace usb
 
 class Device;
 
@@ -60,80 +66,49 @@ class AsyncPluginImpl: public PluginImplInterface, public WidgetObserver {
    * @param plugin The parent Plugin object which is used when creating
    * devices.
    * @param debug_level the debug level to use for libusb.
+   * @param preferences The Preferences container used by the plugin
    */
   AsyncPluginImpl(PluginAdaptor *plugin_adaptor,
                   Plugin *plugin,
-                  unsigned int debug_level);
+                  unsigned int debug_level,
+                  Preferences *preferences);
   ~AsyncPluginImpl();
 
   bool Start();
   bool Stop();
 
-  #ifdef HAVE_LIBUSB_HOTPLUG_API
-  /**
-   * @brief Called when a USB hotplug event occurs.
-   * @param dev the libusb_device the event occurred for.
-   * @param event indicates if the device was added or removed.
-   *
-   * This can be called from either the thread that called
-   * Start(), or from the libusb thread. It can't be called from both threads at
-   * once though, since the libusb thread is only started once the initial call
-   * to libusb_hotplug_register_callback returns.
-   */
-  void HotPlugEvent(struct libusb_device *dev,
-                    libusb_hotplug_event event);
-  #endif
-
+  // These are all run in the main SelectServer thread.
   bool NewWidget(class AnymauDMX *widget);
+  bool NewWidget(class DMXCProjectsNodleU1 *widget);
   bool NewWidget(class EurolitePro *widget);
-  bool NewWidget(class JaRuleWidget *widget);
+  bool NewWidget(ola::usb::JaRuleWidget *widget);
   bool NewWidget(class ScanlimeFadecandy *widget);
   bool NewWidget(class Sunlite *widget);
   bool NewWidget(class VellemanK8062 *widget);
 
-  void WidgetRemoved(class AnymauDMX *widget);
-  void WidgetRemoved(class EurolitePro *widget);
-  void WidgetRemoved(class JaRuleWidget *widget);
-  void WidgetRemoved(class ScanlimeFadecandy *widget);
-  void WidgetRemoved(class Sunlite *widget);
-  void WidgetRemoved(class VellemanK8062 *widget);
-
  private:
   typedef std::vector<class WidgetFactory*> WidgetFactories;
-  typedef std::map<struct libusb_device*, WidgetFactory*> USBDeviceToFactoryMap;
-  typedef std::map<class Widget*, Device*> WidgetToDeviceMap;
-  typedef std::pair<uint8_t, uint8_t> USBDeviceID;
-  typedef std::map<USBDeviceID, struct libusb_device*> USBDeviceIDs;
+  typedef std::map<ola::usb::USBDeviceID, class DeviceState*> USBDeviceMap;
 
   PluginAdaptor* const m_plugin_adaptor;
   Plugin* const m_plugin;
   const unsigned int m_debug_level;
+  std::auto_ptr<ola::usb::HotplugAgent> m_agent;
+  Preferences* const m_preferences;
 
   SyncronizedWidgetObserver m_widget_observer;
-
-  libusb_context *m_context;
-  bool m_use_hotplug;
-  ola::thread::Mutex m_mutex;
-  bool m_suppress_hotplug_events;  // GUARDED_BY(m_mutex);
-  std::auto_ptr<class LibUsbThread> m_usb_thread;
-  std::auto_ptr<class AsyncronousLibUsbAdaptor> m_usb_adaptor;
-
+  ola::usb::AsyncronousLibUsbAdaptor *m_usb_adaptor;  // not owned
   WidgetFactories m_widget_factories;
-  USBDeviceToFactoryMap m_device_factory_map;
-  WidgetToDeviceMap m_widget_device_map;
+  USBDeviceMap m_device_map;
 
-  // Members used if hotplug is not supported
-  ola::thread::timeout_id m_scan_timeout;
-  USBDeviceIDs m_seen_usb_devices;
+  void DeviceEvent(ola::usb::HotplugAgent::EventType event,
+                   struct libusb_device *device);
+  void SetupUSBDevice(libusb_device *device);
 
-  bool HotplugSupported();
-  bool USBDeviceAdded(libusb_device *device);
-  void USBDeviceRemoved(libusb_device *device);
+  template <typename Widget>
+  bool StartAndRegisterDevice(Widget *widget, Device *device);
 
-  bool StartAndRegisterDevice(class Widget *widget, Device *device);
-  void RemoveWidget(class Widget *widget);
-
-  bool ScanUSBDevices();
+  void ShutdownDevice(Device *device, ola::thread::Future<void> *f);
 
   DISALLOW_COPY_AND_ASSIGN(AsyncPluginImpl);
 };
